@@ -1,24 +1,16 @@
 try:
-    import _init_ as lib
-    import fct_Other as oth
-    import fct_Files as fl
+    from . import _lib as lib
+    from . import nutOther as oth
+    from . import nutFiles as fl
 except:
-    import _codeBase._init_ as lib
-    import _codeBase.fct_Other as oth
-    import _codeBase.fct_Files as fl
-# try:
-#     from . import _lib as lib
-#     from . import nutFiles as fl
-#     from . import nutOther as oth
-# except:
-#     try:
-#         import _lib as lib
-#         import nutFiles as fl
-#         import nutOther as oth
-#     except:
-#         from pyNut import _lib as lib
-#         from pyNut import nutFiles as fl
-#         from pyNut import nutOther as oth
+    try:
+        import _lib as lib
+        import nutOther as oth
+        import nutFiles as fl
+    except:
+        from pyNut import _lib as lib
+        from pyNut import nutOther as oth
+        from pyNut import nutFiles as fl
 os = lib.os()
 pd = lib.pandas()
 pyodbc = lib.pyodbc()
@@ -426,13 +418,14 @@ def db_DefineConnectCursor(str_req, str_server=None, str_database=None, df_UID=N
         # --------------------------------
         # Exception: if Database for Log is called, we need to use the server for log (LEGACY)
         #   And not change the default Database - because it cannot connect with Server
-        if not str_database is None:
+        if str_database is None:
+            if '{}.'.format(dbServer.db_Log).lower() in str_req.lower():
+                print('  (**) Database will be |{}| for this request: \n   **{}**'.format(dbServer.db_Log, str_req))
+                dbServer.bl_useLog = True
+        else:
             if dbServer.db_Log.lower() == str_database.lower():
                 print('  (**) Database will be |{}| only for this reqq  \n'.format(dbServer.db_Log))
                 dbServer.bl_useLog = True
-            elif '{}.'.format(dbServer.db_Log).lower() in str_req.lower():
-                print('  (**) Database will be |{}| for this request: \n   **{}**'.format(dbServer.db_Log, str_req))
-                dbServer.bl_useLog = True
             else:
                 dbServer.change_database(str_database)
         # --------------------------------
@@ -482,7 +475,7 @@ def db_MultipleReq(str_req, str_server=None, str_database=None, df_UID=None, t_l
         db_DefineConnectCursor(str_req, str_server, str_database, df_UID, t_logId)
         dbServer.executeReq()
         dbServer.getDataframe_multipleReq()
-        dbServer.db_Commit()
+        dbServer.commit()
     except Exception as err:
         print('  ERROR in db_MultipleReq: {}'.format(err))
         raise
